@@ -1,7 +1,7 @@
 from rest_framework import serializers
 
 from netbox.api.serializers import WritableNestedSerializer
-from netbox_storage.models import Filesystem, Drive, Partition, MountedVolume, LinuxDevice
+from netbox_storage.models import Filesystem, Drive, Partition, MountedVolume, LinuxDevice, LogicalVolume
 
 
 #
@@ -78,3 +78,13 @@ class NestedVolumeGroupSerializer(WritableNestedSerializer):
     class Meta:
         model = MountedVolume
         fields = ["id", "url", "display"]
+
+
+class NestedLogicalVolumeSerializer(WritableNestedSerializer):
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:logicalvolume-detail"
+    )
+
+    class Meta:
+        model = LogicalVolume
+        fields = ["id", "url", "display", "lv_name", "size"]
