@@ -1,7 +1,7 @@
 from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelation
 from django.contrib.contenttypes.models import ContentType
 from django.db import models
-from django.db.models import Sum, CharField
+from django.db.models import Sum, CharField, Manager
 from django.urls import reverse
 
 from netbox.models import NetBoxModel
@@ -30,6 +30,38 @@ class Filesystem(NetBoxModel):
         ordering = ('filesystem', 'description')
 
 
+class LinuxDevice(NetBoxModel):
+    device = models.CharField(
+        max_length=255,
+    )
+    type = models.CharField(
+        max_length=255,
+    )
+    size = models.FloatField(
+        verbose_name='Size (GB)'
+    )
+    content_type = models.ForeignKey(
+        to=ContentType,
+        on_delete=models.CASCADE
+    )
+    object_id = models.PositiveBigIntegerField()
+    object = GenericForeignKey(
+        ct_field='content_type',
+        fk_field='object_id'
+    )
+
+    clone_fields = ['device', 'type', 'size', 'content_type', 'object_id']
+
+    class Meta:
+        ordering = ['device', 'type', 'size', 'content_type', 'object_id']
+
+    def __str__(self):
+        return f'{self.device} ({self.type})'
+
+    def get_absolute_url(self):
+        return reverse('plugins:netbox_storage:linuxdevice', kwargs={'pk': self.pk})
+
+
 class Drive(NetBoxModel):
     cluster = models.ForeignKey(
         to='virtualization.Cluster',
@@ -91,38 +123,6 @@ class Drive(NetBoxModel):
         return self.size - current_partition_allocated_space
 
 
-class LinuxDevice(NetBoxModel):
-    device = models.CharField(
-        max_length=255,
-    )
-    type = models.CharField(
-        max_length=255,
-    )
-    size = models.FloatField(
-        verbose_name='Size (GB)'
-    )
-    content_type = models.ForeignKey(
-        to=ContentType,
-        on_delete=models.CASCADE
-    )
-    object_id = models.PositiveBigIntegerField()
-    object = GenericForeignKey(
-        ct_field='content_type',
-        fk_field='object_id'
-    )
-
-    clone_fields = ['device', 'type', 'size', 'content_type', 'object_id']
-
-    class Meta:
-        ordering = ['device', 'type', 'size', 'content_type', 'object_id']
-
-    def __str__(self):
-        return f'{self.device} ({self.type})'
-
-    def get_absolute_url(self):
-        return reverse('plugins:netbox_storage:linuxdevice', kwargs={'pk': self.pk})
-
-
 class Partition(NetBoxModel):
     drive = models.ForeignKey(
         Drive,
