@@ -2,10 +2,10 @@ from netbox.views import generic
 
 from netbox_storage.filters import LogicalVolumeFilter
 from netbox_storage.forms import (
-    # LogicalVolumeImportForm,
+    LogicalVolumeImportForm,
     LogicalVolumeFilterForm,
     LogicalVolumeForm,
-    # LogicalVolumeBulkEditForm
+    LogicalVolumeBulkEditForm
 )
 from netbox_storage.models import LogicalVolume
 from netbox_storage.tables import LogicalVolumeTable
@@ -33,7 +33,6 @@ class LogicalVolumeDeleteView(generic.ObjectDeleteView):
     default_return_url = "plugins:netbox_storage:logicalvolume_list"
 
 
-"""
 class LogicalVolumeBulkImportView(generic.BulkImportView):
     queryset = LogicalVolume.objects.all()
     model_form = LogicalVolumeImportForm
@@ -51,4 +50,3 @@ class LogicalVolumeBulkEditView(generic.BulkEditView):
 class LogicalVolumeBulkDeleteView(generic.BulkDeleteView):
     queryset = LogicalVolume.objects.all()
     table = LogicalVolumeTable
-"""
